Remove rocshmem_timer function

Этот коммит содержится в:
avinashkethineedi
2025-02-17 07:16:49 +00:00
родитель c155636da4
Коммит 21dbd5cc5e
3 изменённых файлов: 2 добавлений и 19 удалений
-11
Просмотреть файл
@@ -512,17 +512,6 @@ __device__ ATTR_NO_INLINE void rocshmem_wg_team_sync(rocshmem_team_t team);
*/
__device__ ATTR_NO_INLINE void *rocshmem_ptr(const void *dest, int pe);
/**
* @brief Query the current time. Similar to gettimeofday() on the CPU. To use
* this function, rocSHMEM must be configured with profiling support
* (--enable-profile).
*
* Can be called per thread with no performance penalty.
*
* @return Time in micro-seconds.
*/
__device__ uint64_t rocshmem_timer();
/**
* @brief Make all uncacheable GPU data visible to other agents in the sytem.
*
-6
Просмотреть файл
@@ -638,12 +638,6 @@ __device__ int rocshmem_my_pe() {
return get_internal_ctx(ROCSHMEM_CTX_DEFAULT)->my_pe;
}
__device__ uint64_t rocshmem_timer() {
GPU_DPRINTF("Function: rocshmem_timer\n");
return __read_clock();
}
template <typename T>
__device__ T rocshmem_atomic_fetch_add(rocshmem_ctx_t ctx, T *dest, T val,
int pe) {
+2 -2
Просмотреть файл
@@ -141,10 +141,10 @@ class Stats {
StatType stats[I] = {0};
public:
__device__ uint64_t startTimer() const { return rocshmem_timer(); }
__device__ uint64_t startTimer() const { return wall_clock64(); }
__device__ void endTimer(uint64_t start, int index) {
incStat(index, rocshmem_timer() - start);
incStat(index, wall_clock64() - start);
}
__device__ void incStat(int index, int value = 1) {